@@ -1,6 +1,7 @@
 from compare3.errors import UnmetExpectation
 from logging import Logger
 from numbers import Number
+import inspect
 import re
 
 class Expression(object):
@@ -38,6 +39,23 @@ class Expression(object):
     def __init__(self, value):
         self._determinant: bool = True
         self.value = value
+        frame = inspect.currentframe()
+        frame = inspect.getouterframes(frame)[1]
+        string = inspect.getframeinfo(frame[0]).code_context[0].strip()
+        class_name="expect"
+        for key in frame[0].f_locals.keys():
+            if frame[0].f_locals == self.__class__:
+                class_name = key
+                break
+
+        match_pattern=".*{}\(([a-zA-Z0-9\s\"\'_\-\.]*)\)(\.|\n).*".format(class_name)
+        arg_match=re.fullmatch(match_pattern, string)
+
+        if arg_match is not None:
+            arg_name=arg_match.group(1)
+            self._value_name = arg_name
+        else:
+            self._value_name = None
 
     def _ensure(self, expression, value_to_match, message):
         if self._determinant:
@@ -50,12 +68,20 @@ class Expression(object):
         return self
 
     def _message(self, expected, actual=None, msg_type="equal to"):
-        msg = "'{}' is {}{} '{}'".format(expected, "not " if self._determinant else "", msg_type, actual)
+        msg = "{}'{}' is {}{} '{}'".format(self._value_name+": " if self._value_name is not None else "", expected, "not " if self._determinant else "", msg_type, actual)
         return msg
 
     def log(self, msg):
         return self.__class__.logger.log(self.__class__.comparison_log_level, msg)
 
+    def log_evaluation(self, eval_type, value=None):
+        self.log("{}checking if '{}' is{} {} {}".format(
+            self._value_name+": " if self._value_name is not None else "",
+            self.value,
+           " not" if not self._determinant else "",
+           eval_type,
+           f"'{value}'" if value is not None else ""))
+
     @property
     def is_(self) -> 'Expression':
         self._determinant = True
@@ -72,69 +98,69 @@ class Expression(object):
         return self
 
     def equal_to(self, value):
-        self.log("checking if '{}'{} equal_to '{}'".format(self.value," not" if self._determinant else "",value))
+        self.log_evaluation('equal to', value)
         return self._ensure(self.value == value, True, self._message(self.value, value))
 
     def equal_to_as_strings(self, value):
-        self.log("checking if '{}'{} equal_to_as_strings '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('equal as strings', value)
         return self._ensure(str(self.value) == str(value), True, self._message(self.value, value))
 
     def equal_to_as_integer(self, value):
-        self.log("checking if '{}'{} equal_to_as_integer '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('equal as integers', value)
         return self._ensure(int(self.value) == int(value), True, self._message(int(self.value), int(value)))
 
     def equal_to_as_floating_point(self, value):
-        self.log("checking if '{}'{} equal_to_as_floating_point '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('equal as floats', value)
         return self._ensure(float(self.value) == float(value), True, self._message(float(self.value), float(value)))
 
     def greater_than(self, value):
-        self.log("checking if '{}'{} greater_than '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('greater than', value)
         return self._ensure(self.value > value, True, self._message(self.value, value, "greater than"))
 
     def greater_than_or_equal_to(self, value):
-        self.log("checking if '{}'{} greater_than_or_equal_to '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('greater than or equal to', value)
         return self._ensure(self.value >= value, True, self._message(self.value, value, "greater than or equal to"))
 
     def less_than(self, value):
-        self.log("checking if '{}'{} less_than '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('less than', value)
         return self._ensure(self.value < value, True, self._message(self.value, value, "less than"))
 
     def less_than_or_equal_to(self, value):
-        self.log("checking if '{}'{} less_than_or_equal_to '{}'".format(self.value, " not" if self._determinant else "", value))
+        self.log_evaluation('less than or equal to', value)
         return self._ensure(self.value <= value, True, self._message(self.value, value, "less than or equal to"))
 
     def none(self):
-        self.log("checking if '{}' is{} None".format(self.value, " not" if self._determinant else ""))
+        self.log_evaluation('None')
         return self._ensure(self.value is None, True,
-                            "{} is{} None".format(self.value, " not" if self._determinant else ""))
+                            "{} is{} None".format(self.value, " not" if not self._determinant else ""))
 
     def truthy(self):
-        self.log("checking if '{}' is{} truthy".format(self.value, " not" if self._determinant else ""))
+        self.log_evaluation("truthy")
         return self._ensure(bool(self.value), True,
-                            "{} {} truthy".format(self.value, "doesn't seem" if self._determinant else "seems"))
+                            "{} {} truthy".format(self.value, "doesn't seem" if not self._determinant else "seems"))
 
     def falsy(self):
-        self.log("checking if '{}' is{} falsy".format(self.value, " not" if self._determinant else ""))
+        self.log_evaluation("falsy")
         return self._ensure(bool(self.value), False,
-                            "{} {} falsy".format(self.value, "doesn't seem" if self._determinant else "seems"))
+                            "{} {} falsy".format(self.value, "doesn't seem" if not self._determinant else "seems"))
 
     def contains(self, value):
-        self.log("checking if '{}' is{} in '{}'".format(value, " not" if self._determinant else "", self.value))
+        self.log_evaluation("in", value)
         return self._ensure(value in self.value, True,
-                            "{} was{} in {}".format(self.value, " not" if self._determinant else "", value))
+                            "{} was{} in {}".format(self.value, " not" if not self._determinant else "", value))
 
     def numeric(self):
-        self.log("checking if '{}' is{} numeric".format(self.value, " not" if self._determinant else ""))
+        self.log_evaluation('numeric')
         return self._ensure(isinstance(self.value, Number), True,
-                            "{} {} numeric".format(self.value, "doesn't seem" if self._determinant else "seems"))
+                            "{} {} numeric".format(self.value, "doesn't seem" if not self._determinant else "seems"))
 
     def alphabetical(self):
-        self.log("checking if '{}' is{} alphabetical".format(self.value, " not" if self._determinant else ""))
+        self.log_evaluation('alphabetical')
         return self._ensure(re.fullmatch("[a-zA-Z]*", self.value) is not None, True,
                             "{} {} alphabetical".format(self.value, "doesn't seem" if self._determinant else "seems"))
 
     def alphanumeric(self):
-        self.log("checking if '{}' is{} alphanumeric".format(self.value, " not" if self._determinant else ""))
+        self.log_evaluation('alphanumeric')
         return self._ensure(re.fullmatch("[a-zA-Z0-9]*", self.value) is not None, True,
                             "{} {} alphabetical".format(self.value, "doesn't seem" if self._determinant else "seems"))
 
@@ -191,7 +217,7 @@ class Callable(Expression):
         self.log("Calling {} with:\nargs: {}\nkwargs:{}".format(self.value.__name__, self.args,self.kwargs))
         return_val = self.value(*self.args, **self.kwargs)
 
-        self.log("checking if return: {} is{} equal to {}".format(return_val, " not" if self._determinant else "", expected))
+        self.log("checking if return: {} is{} equal to {}".format(return_val, " not" if not self._determinant else "", expected))
         self._ensure(return_val == expected, True,
                      "{} {}return {}, it returned {} instead".format(self.value,
                                                                      "did not " if self._determinant else "",
@@ -209,7 +235,7 @@ class Callable(Expression):
             self._ensure(isinstance(e, exception_type),
                          True,
                          "{} {}raise {}, it returned {} instead".format(self.value.__name__,
-                                                                        "did not " if self._determinant else "",
+                                                                        "did not " if not self._determinant else "",
                                                                         exception_type.__class__.__name__,
                                                                         e.__class__.__name__))
             if exception_message is not None:
